# Gro API Client examples: Crop Models

1. Follow the [instructions to install the Gro API Client](../../../../README.md)
1. Download the [requirements file in this directory](./requirements.txt)
2. Run `pip install -r requirements.txt` (for MacOS and Linux) or `conda install --file requirements.txt` (for Windows) to automatically install the required dependencies
3. Download the example code (either <example>.ipynb notebook or <example>.py program) to your working directory
4. Run the example (either `jupyter notebook` or `python <example>.py`)
